/**
 * Bull SAS / OW2 Orchestra
 * Copyright (C) 2010 Bull S.A.S, and individual contributors as indicated
 * by the @authors tag.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */
package org.ow2.orchestra.designer.bpmn.views {
import org.ow2.orchestra.designer.bpmn.model.AbstractElement;
import org.ow2.orchestra.designer.bpmn.model.FlowModel;
import org.ow2.orchestra.designer.bpmn.model.IIdentifiableElement;
import org.ow2.orchestra.designer.bpmn.model.data.ExpressionDataInputModel;
import org.ow2.orchestra.designer.bpmn.model.data.ExpressionDataObjectModel;
import org.ow2.orchestra.designer.bpmn.model.process.EventModel;
import org.ow2.orchestra.designer.bpmn.model.process.GatewayModel;
import org.ow2.orchestra.designer.bpmn.model.process.PoolModel;
import org.ow2.orchestra.designer.bpmn.model.process.SequenceFlowModel;
import org.ow2.orchestra.designer.bpmn.model.process.TaskModel;
import org.ow2.orchestra.designer.bpmn.views.data.DataMappingView;
import org.ow2.orchestra.designer.bpmn.views.data.ExpressionDataInputView;
import org.ow2.orchestra.designer.bpmn.views.data.ExpressionDataObjectView;
import org.ow2.orchestra.designer.bpmn.views.process.EventView;
import org.ow2.orchestra.designer.bpmn.views.process.GatewayView;
import org.ow2.orchestra.designer.bpmn.views.process.PoolView;
import org.ow2.orchestra.designer.bpmn.views.process.ProcessView;
import org.ow2.orchestra.designer.bpmn.views.process.SequenceFlowView;
import org.ow2.orchestra.designer.bpmn.views.process.TaskView;

/**
 * Factory of bpmn views.
 *
 * @author Loic Albertin
 *
 */
public class ViewFactory {
  public function ViewFactory() {
  }

  /**
   * Instantiates an AbstractElementView according to the given model type.
   * For example if the given model is an instance of @see(org.ow2.orchestra.designer.bpmn.model.GatewayModel)
   * this method will returns an instance of @see(org.ow2.orchestra.designer.bpmn.views.GatewayView).
   *
   * <b>Warning:</b> This method also associate (using view constructor) the view with the <b>given</b> model.
   *
   * @param model the model for which a corresponding view should be instantiated
   * @return returns an element view instance according to the given model
   *
   */
  public static function getViewByModel(model:AbstractElement, flowView:AbstractDiagramView):AbstractElementView {
    var view:AbstractElementView = null;
    if (model is FlowModel && !(model is SequenceFlowModel)) {
      view = new FlowView(model as FlowModel, flowView);
    } else     if (flowView is ProcessView) {
      if (model is GatewayModel) {
        view = new GatewayView(model as GatewayModel);
      } else if (model is EventModel) {
        view = new EventView(model as EventModel);
      } else if (model is TaskModel) {
        view = new TaskView(model as TaskModel, flowView as ProcessView);
      } else if (model is PoolModel) {
        view = new PoolView(model as PoolModel);
      } else if (model is SequenceFlowModel) {
        view = new SequenceFlowView(model as SequenceFlowModel, flowView);
      }
    } else if (flowView is DataMappingView) {
      if (model is ExpressionDataObjectModel) {
        view = new ExpressionDataObjectView(model as ExpressionDataObjectModel);
      } else if (model is ExpressionDataInputModel) {
        view = new ExpressionDataInputView(model as ExpressionDataInputModel);
      }
    }


    // Add automationName for UI testing
    if (view != null) {
      if (model is IIdentifiableElement) {
        view.automationName = "view" + IIdentifiableElement(model).id;
      }
    }
    return view;
  }

}
}
